@@ -7,7 +7,6 @@ from sqlalchemy.orm import backref, sessionmaker
 from snowav.database.tables import Base, RunMetadata, Watershed, Basin, Results, VariableUnits
 import pandas as pd
 import snowav
-import smrf
 import numpy as np
 import copy
 import urllib.parse
@@ -15,9 +14,23 @@ import mysql.connector
 from sys import exit
 import warnings
 
-warnings.filterwarnings("ignore")
-import awsm
-warnings.filterwarnings("default")
+# Fix these two by pulling smrf and awsm versions from netcdf
+try:
+    import smrf
+    smrf_version = smrf.__version__
+except:
+    print('Could not import smrf, database smrf version will be "unknown"')
+    smrf_version = 'unknown'
+
+try:
+    warnings.filterwarnings("ignore")
+    import awsm
+    warnings.filterwarnings("default")
+    awsm_version = awsm.__version__
+
+except:
+    print('Could not import awsm, database awsm version will be "unknown"')
+    awsm_version = 'unknown'
 
 def make_session(connector):
     '''
@@ -111,7 +124,10 @@ def collect(connector, plotorder, basins, start_date, end_date, value,
 
     value_options = ['swe_z','swe_vol','density','precip_z','precip_vol',
                      'rain_z','rain_vol','swe_avail','swe_unavail','coldcont',
-                     'swi_z','swi_vol','depth','snow_line','mean_air_temp']
+                     'swi_z','swi_vol','depth','snow_line','mean_air_temp',
+                     'evap_z', 'L_v_E','melt','lwc','temp_surface',
+                     'temp_lower','temp_bulk','depth_lower_layer','h20_sat',
+                     'R_n','H','G','M','delta_Q']
 
     method_options = ['sum','difference','daily','end']
 
@@ -163,7 +179,7 @@ def collect(connector, plotorder, basins, start_date, end_date, value,
                     df = df.rename(columns={'value':bid})
 
                 else:
-                    df.loc[e.index,bid] = e['value'].values
+                    df[bid] = e['value']
 
             df.sort_index(inplace=True)
 
@@ -177,7 +193,18 @@ def collect(connector, plotorder, basins, start_date, end_date, value,
                                     'elev={}, {} to {}'. format(run_name, elev,
                                     start_date, end_date))
                 else:
-                    df.loc[elev,bid] = e['value'].values
+                    if e['value'].values[0] is None:
+                        df.loc[elev,bid] = np.nan
+                    else:
+
+                        # The database can occasionally get multiple values
+                        # for the same record if it doesn't exit cleanly
+                        if len(e['value'].values) == 1:
+                            df.loc[elev,bid] = e['value'].values
+                        else:
+                            raise Exception('Multiple database entries for a '
+                                'single field, consider running with '
+                                '[database] overwrite: True')
 
         if method == 'difference':
             for elev in edges:
@@ -204,7 +231,9 @@ def collect(connector, plotorder, basins, start_date, end_date, value,
                                     'elev={}, {} to {}'. format(run_name, elev,
                                     start_date, end_date))
                 else:
-                    df.loc[elev,bid] = e['value'].sum()
+                    df.loc[elev,bid] = e['value'].sum(skipna=False)
+
+    df = df[plotorder]
 
     return df
 
@@ -291,7 +320,7 @@ def delete(connector, basins, start_date, end_date, bid, run_name):
     basin_id = int(basins[bid]['basin_id'])
     session = make_session(connector)
 
-    logger.append(' Deleting existing database records for {}, {}, {} '.format(
+    logger.append(' Deleting existing records for {}, {}, {} '.format(
                   bid, run_name, start_date.date()))
 
     # Get the run_id
@@ -420,8 +449,8 @@ def run_metadata(self, run_name):
               'watershed_id':int(watershed_id),
               'pixel':int(self.pixel),
               'description':'',
-              'smrf_version':'smrf'+ smrf.__version__,
-              'awsm_version':'aswm'+ awsm.__version__,
+              'smrf_version':'smrf'+ smrf_version,
+              'awsm_version':'aswm'+ awsm_version,
               'snowav_version':'snowav'+ snowav.__version__,
               'data_type':'',
               'data_location':trdir,
@@ -432,7 +461,8 @@ def run_metadata(self, run_name):
     insert(self.connector, 'RunMetadata', values)
 
     self.vid = {}
-    for v in self.vars.keys():
+    for v in [*self.vars.keys()]:
+        u = self.vars[v]['units']
         if (('vol' in v) or ('avail' in v)):
             u = self.units
         if (('z' in v) or (v == 'depth')):
@@ -445,7 +475,7 @@ def run_metadata(self, run_name):
         variables = {'run_id':self.run_id,
                      'variable':v,
                      'unit':u,
-                     'name':self.vars[v]}
+                     'name':self.vars[v]['description']}
 
         insert(self.connector,'VariableUnits',variables)
 
@@ -454,7 +484,7 @@ def run_metadata(self, run_name):
         qry = session.query(VariableUnits).filter(VariableUnits.run_id == self.run_id)
         session.close()
         df = pd.read_sql(qry.statement, qry.session.connection())
-        self.vid[v] = df['id'].values[0]
+        self.vid[v] = df[df['variable'] == v]['id'].values[0]
 
     # snow_line
     variables = {'run_id':self.run_id,
@@ -491,7 +521,8 @@ def run_metadata(self, run_name):
         qry = session.query(VariableUnits).filter(VariableUnits.run_id == self.run_id)
         session.close()
         df = pd.read_sql(qry.statement, qry.session.connection())
-        self.vid[v] = df['id'].values[0]
+
+        self.vid[v] = df[df['variable'] == v]['id'].values[0]
 
 
 def connect(sqlite = None, sql = None, plotorder = None, user = None,
@@ -575,9 +606,10 @@ def connect(sqlite = None, sql = None, plotorder = None, user = None,
         except:
             dbs = [i[0] for i in dbs]
 
-        db_engine = 'mysql+mysqlconnector://{}:{}@{}/{}'.format(user,
+        db_engine = 'mysql+mysqlconnector://{}:{}@{}:{}/{}'.format(user,
                                                                 password,
                                                                 host,
+                                                                port,
                                                                 sql)
 
         # If the database doesn't exist, create it, otherwise connect
@@ -671,9 +703,12 @@ def connect(sqlite = None, sql = None, plotorder = None, user = None,
 
     # Initialize basins within the watershed
     for i,name in enumerate(plotorder):
+
+        # This logic doesn't work if trying to 'move' a subbasin from one watershed to another,
+        # i.e., 'Cherry Creek' going from part of the Extended Tuolumne to Tuolumne River
+        # Basin in wy2020
         if name in bs['basin_name'].values:
-            f = bs[bs['basin_name'].values == name]
-            bid = f['basin_id'].values[0]
+            bid = int(bs[(bs['watershed_id'] == wid) & (bs['basin_name'] == name)]['basin_id'].values[0])
 
         else:
             logger.append(' {} not found as a basin in '.format(name) +
