@@ -1,8 +1,10 @@
 
+import os
 import numpy as np
 import pandas as pd
 import copy
-from datetime import datetime
+from datetime import datetime, timedelta
+from tablizer.tablizer import get_existing_records
 from snowav.plotting.swi import swi
 from snowav.plotting.basin_total import basin_total
 from snowav.plotting.cold_content import cold_content
@@ -12,14 +14,19 @@ from snowav.plotting.flt_image_change import flt_image_change
 from snowav.plotting.image_change import image_change
 from snowav.plotting.precip_depth import precip_depth
 from snowav.plotting.stn_validate import stn_validate
-from snowav.plotting.swe_change import swe_change
 from snowav.plotting.write_properties import write_properties
 from snowav.plotting.swe_volume import swe_volume
+from snowav.plotting.inputs import inputs
 from snowav.inflow.inflow import inflow
 from snowav.plotting.diagnostics import diagnostics
 from snowav.plotting.plotlims import plotlims
+from snowav.plotting.point_values import point_values
 from snowav.database.database import collect
 from snowav.plotting.plotlims import plotlims as plotlims
+import matplotlib as mpl
+
+if os.environ.get('DISPLAY','') == '':
+    mpl.use('Agg')
 
 def figures(self):
     '''
@@ -81,9 +88,12 @@ def figures(self):
 
         self.flight_diff_fig_names, self.flight_delta_vol_df = flt_image_change(args, self._logger)
 
+        if self.flight_diff_fig_names == []:
+            self.flt_flag = False
+
     if self.swi_flag:
         image = np.zeros_like(self.outputs['swi_z'][0])
-        for n in range(self.ixs,self.ixe):
+        for n in range(self.ixs,self.ixe+1):
             image = image + self.outputs['swi_z'][n]*self.depth_factor
 
         df = collect(connector, args['plotorder'], args['basins'],
@@ -93,8 +103,8 @@ def figures(self):
         args['df'] = df
         args['image'] = image
         args['title'] = 'Accumulated SWI\n{} to {}'.format(
-                        self.start_date.date().strftime("%Y-%-m-%-d"),
-                        self.end_date.date().strftime("%Y-%-m-%-d"))
+                        args['report_start'],
+                        args['report_date'])
 
         fig_names['swi'] = swi(args, self._logger)
 
@@ -112,7 +122,7 @@ def figures(self):
 
         args['df'] = df
         args['image'] = image*self.depth_factor
-        args['title'] = 'Change in SWE Depth\n{} to {}'.format(
+        args['title'] = 'Change in SWE\n{} to {}'.format(
                         args['report_start'], args['report_date'])
 
         fig_names['image_change'] = image_change(args, self._logger)
@@ -174,7 +184,7 @@ def figures(self):
 
     if self.precip_depth_flag:
         swi_image = np.zeros_like(self.outputs['swi_z'][0])
-        for n in range(self.ixs,self.ixe):
+        for n in range(self.ixs,self.ixe+1):
             swi_image = swi_image + self.outputs['swi_z'][n]*self.depth_factor
 
         swi_df = collect(connector, args['plotorder'], args['basins'],
@@ -212,10 +222,10 @@ def figures(self):
         swe_per = collect(connector, args['plotorder'], args['basins'],
                          args['start_date'], args['end_date'], 'swe_z',
                          args['run_name'], args['edges'], 'daily')
-        density = collect(connector, args['plotorder'], args['basins'],
+        rho = collect(connector, args['plotorder'], args['basins'],
                          wy_start, args['end_date'], 'density',
                          args['run_name'], args['edges'], 'daily')
-        density_per = collect(connector, args['plotorder'], args['basins'],
+        rho_per = collect(connector, args['plotorder'], args['basins'],
                          args['start_date'], args['end_date'], 'density',
                          args['run_name'], args['edges'], 'daily')
         snow_line = collect(connector, args['plotorder'], args['basins'],
@@ -224,6 +234,12 @@ def figures(self):
         snow_line_per = collect(connector, args['plotorder'], args['basins'],
                          args['start_date'], args['end_date'], 'snow_line',
                          args['run_name'], args['edges'], 'daily')
+        evap_z = collect(connector, args['plotorder'], args['basins'],
+                         wy_start, args['end_date'], 'evap_z',
+                         args['run_name'], args['edges'], 'daily')
+        evap_z_per = collect(connector, args['plotorder'], args['basins'],
+                         args['start_date'], args['end_date'], 'evap_z',
+                         args['run_name'], args['edges'], 'daily')
 
         snow_line_per = snow_line_per.fillna(0)
         first_row = snow_line_per.iloc[[0]].values[0]
@@ -236,10 +252,15 @@ def figures(self):
         first_row = swe_per.iloc[[0]].values[0]
         swe_per = swe_per.apply(lambda row: row - first_row, axis=1)
 
-        density = density.fillna(0)
-        density_per = density_per.fillna(0)
-        first_row = density_per.iloc[[0]].values[0]
-        density_per = density_per.apply(lambda row: row - first_row, axis=1)
+        evap_z = evap_z.fillna(0)
+        evap_z_per = evap_z_per.fillna(0)
+        first_row = evap_z_per.iloc[[0]].values[0]
+        evap_z_per = evap_z_per.apply(lambda row: row - first_row, axis=1)
+
+        rho = rho.fillna(0)
+        rho_per = rho_per.fillna(0)
+        first_row = rho_per.iloc[[0]].values[0]
+        rho_per = rho_per.apply(lambda row: row - first_row, axis=1)
 
         precip = precip.fillna(0)
         precip_per = precip_per.fillna(0)
@@ -257,8 +278,10 @@ def figures(self):
         args['precip_per'] = precip_per
         args['swe'] = swe
         args['swe_per'] = swe_per
-        args['density'] = density
-        args['density_per'] = density_per
+        args['evap_z'] = evap_z
+        args['evap_z_per'] = evap_z_per
+        args['density'] = rho
+        args['density_per'] = rho_per
         args['elevlbl'] = self.elevlbl
 
         diagnostics(args, self._logger)
@@ -290,9 +313,84 @@ def figures(self):
         if not flag:
             self.stn_validate_flag = False
 
+    if self.point_values_flag and self.point_values:
+
+        # check that self.point_values_date falls within options
+        pv_date = self.point_values_date
+
+        if pv_date is None:
+            self._logger.info(' Value in [validate] point_values_date being '
+                              'assigned to {}'.format(
+                              self.end_date.date().strftime("%Y-%m-%d")))
+            pv_date = self.end_date
+
+        if pv_date < self.start_date or pv_date > self.end_date:
+            self._logger.info(' Value in [validate] point_values_date outside '
+                              'of range in [run] start_date - end_date, '
+                              'point_values_date being assigned to {}'.format(
+                              self.end_date.date().strftime("%Y-%m-%d")))
+            pv_date = self.end_date
+            idx = -1
+
+        else:
+            # get index for self.outputs for that date
+            x = np.abs([date - pv_date for date in self.outputs['dates']])
+            idx = x.argmin(0)
+
+        model_date = self.outputs['dates'][idx]
+        model_date = model_date.date().strftime('%Y-%m-%d')
+        course_date = self.point_values_date.date().strftime('%Y-%m-%d')
+        nsubplots = (self.point_values_settings[3]*self.point_values_settings[4]-1)-1
+
+        for idxp, value in enumerate(self.point_values_properties):
+            pflag = True
+            df = pd.read_csv(self.point_values_csv[idxp])
+
+            if self.point_values_heading[idxp] is not None:
+                check_headings = [self.point_values_heading[idxp],'name',
+                                  'latitude','longitude']
+            else:
+                check_headings = ['name', 'latitude', 'longitude']
+
+            for head in check_headings:
+                if head not in df.columns.tolist():
+                    self._logger.warn(' Config option [validate] '
+                        'point_values_heading: {} not in headings {} in '
+                        '{}, setting point_values: False'.format(head,
+                        df.columns.tolist(), self.point_values_csv[idxp]))
+                    pflag = False
+
+            if not pflag:
+                continue
+
+            if len(df.name.unique()) > nsubplots:
+                self._logger.warn(' Number of subplots that will be generated in '
+                                  'point_values() may not fit well with settings '
+                                  'in point_values_settings, consider changing '
+                                  'nrows and/or ncols in [validate] '
+                                  'point_values_settings')
+
+            fig_name = '{}model_pixel_{}_{}.csv'.format(self.figs_path,
+                        value, self.end_date.date().strftime("%Y%m%d"))
+
+            if value == 'swe_z':
+                factor = self.depth_factor
+
+            if value == 'density':
+                factor = 1
+
+            if value == 'depth':
+                factor = 39.37
+
+            array = self.outputs[value][idx]*factor
+
+            point_values(array, value, df, (self.snow_x, self.snow_y), fig_name,
+                         self.dem, self.figs_path, self.veg_type,
+                         self.point_values_heading[idxp], model_date, course_date,
+                         self.point_values_settings, self.pixel, self._logger)
+
     if self.compare_runs_flag:
         args['variables'] = ['swe_vol','swi_vol']
-        wy_start = datetime(self.wy-1,10,1)
 
         if self.flt_flag:
             args['flag'] = True
@@ -302,12 +400,18 @@ def figures(self):
         dict = {}
         for var in args['variables']:
             dict[var] = {}
-            for run in self.compare_run_names:
+            for wy, run in zip(self.compare_run_wys, self.compare_run_names):
+                wy_start = datetime(wy-1,10,1)
                 df = collect(connector, args['plotorder'][0], args['basins'],
                              wy_start,args['end_date'],var,run,'total','daily')
+
+                if wy != self.wy:
+                    adj = self.wy - wy
+                    df.index = df.index + timedelta(days = 365*adj)
+
                 if var == 'swi_vol':
                     df = df.cumsum()
-                    
+
                 dict[var][run] = df
 
         args['dict'] = dict
@@ -332,6 +436,7 @@ def figures(self):
             args['inflow_summary'] = pd.read_csv(self.summary_csv,
                                                  parse_dates=[0], index_col = 0)
 
+
         args['inflow_headings'] = self.inflow_headings
         args['basin_headings'] = self.basin_headings
 
@@ -341,7 +446,69 @@ def figures(self):
         args['connector'] = self.connector
         args['wy_start'] = datetime(self.wy-1,10,1)
 
-        write_properties(args, self.write_properties)
+        write_properties(args, self.write_properties, self._logger)
+
+    if self.inputs_fig_flag:
+
+        if self.mysql is not None:
+            dbs = 'sql'
+        else:
+            dbs = 'sqlite'
+
+        df = get_existing_records(connector, dbs)
+        df = df.set_index('date_time')
+        df.sort_index(inplace=True)
+
+        ivalue = {}
+        p = []
+
+        for var in self.plots_inputs_variables:
+            ivalue[var] = {}
+
+            for basin in self.inputs_basins:
+                bid = args['basins'][basin]['basin_id']
+                ivalue[var][basin] = {}
+
+                for func in self.inputs_methods:
+
+                    if 'percentile' in func:
+                        nfunc = '{}_{}'.format(func,str(self.inputs_percentiles[0]))
+
+                        if ((var == self.plots_inputs_variables[0]) and
+                             (basin == self.inputs_basins[0])):
+                            p.append(nfunc)
+
+                        ivalue[var][basin][nfunc] =  df[(df['function'] == nfunc) &
+                                       (df['variable'] == var) &
+                                       (df['basin_id'] == int(bid)) &
+                                       (df['run_name'] == args['run_name'])]
+
+                        nfunc = '{}_{}'.format(func,str(self.inputs_percentiles[1]))
+
+                        if ((var == self.plots_inputs_variables[0]) and
+                             (basin == self.inputs_basins[0])):
+                            p.append(nfunc)
+
+                        ivalue[var][basin][nfunc] =  df[(df['function'] == nfunc) &
+                                       (df['variable'] == var) &
+                                       (df['basin_id'] == int(bid)) &
+                                       (df['run_name'] == args['run_name'])]
+                    else:
+                        ivalue[var][basin][func] =  df[(df['function'] == func) &
+                                       (df['variable'] == var) &
+                                       (df['basin_id'] == int(bid)) &
+                                       (df['run_name'] == args['run_name'])]
+
+                        if ((var == self.plots_inputs_variables[0]) and
+                             (basin == self.inputs_basins[0])):
+                            p.append(func)
+
+        args['inputs'] = ivalue
+        args['inputs_methods'] = p
+        args['var_list'] = self.plots_inputs_variables
+        args['inputs_basins'] = self.inputs_basins
+
+        inputs(args, self._logger)
 
     if self.forecast_flag:
         print('Forecast figures in progress...')
