@@ -7,15 +7,18 @@ import logging
 import coloredlogs
 import os
 import pandas as pd
-import datetime
+from datetime import datetime
 import copy
+import calendar
 
-def read_config(self, external_logger=None, awsm=None):
+def read_config(self, external_logger = None, awsm = None, end_date = None):
     '''
     Read snowav config file.
 
     '''
 
+    print('Reading {} and loading files...'.format(self.config_file))
+
     snowav_mcfg = MasterConfig(modules = 'snowav')
     ucfg = get_user_config(self.config_file, mcfg=snowav_mcfg)
     ucfg.apply_recipes()
@@ -30,6 +33,8 @@ def read_config(self, external_logger=None, awsm=None):
     self.tmp_err = []
     self.tmp_warn = []
 
+    self.proc_time_start = datetime.now()
+
     ####################################################
     #            snowav                                #
     ####################################################
@@ -37,22 +42,13 @@ def read_config(self, external_logger=None, awsm=None):
     self.log_to_file = ucfg.cfg['snowav']['log_to_file']
     self.save_path = ucfg.cfg['snowav']['save_path']
     self.units = ucfg.cfg['snowav']['units']
-    self.filetype = ucfg.cfg['snowav']['filetype']
     self.elev_bins = ucfg.cfg['snowav']['elev_bins']
     self.directory = ucfg.cfg['snowav']['directory']
     self.dempath = ucfg.cfg['snowav']['dempath']
     self.run_name = ucfg.cfg['snowav']['run_name']
     self.plotorder = ucfg.cfg['snowav']['masks']
-    self.print_db_connection = ucfg.cfg['snowav']['print_db_connection']
-
-    if self.plotorder is not None and type(self.plotorder) != list:
-        self.plotorder = [self.plotorder]
-
     self.plotlabels = ucfg.cfg['snowav']['plotlabels']
 
-    if self.plotlabels is not None and type(self.plotlabels) != list:
-        self.plotlabels = [self.plotlabels]
-
     ####################################################
     #           run                                    #
     ####################################################
@@ -61,6 +57,15 @@ def read_config(self, external_logger=None, awsm=None):
     self.start_date = ucfg.cfg['run']['start_date']
     self.end_date = ucfg.cfg['run']['end_date']
 
+    if end_date is not None:
+        self.end_date = end_date
+        self.tmp_log.append(' Overriding config end_date with '
+                            '{} given with snowav call'.format(end_date))
+
+        if self.end_date <= self.start_date:
+            raise Exception('end_date {} earlier than start_date {}'.format(
+                            self.end_date, self.start_date))
+
     if self.start_date is not None and self.end_date is not None:
         self.start_date = self.start_date.to_pydatetime()
         self.end_date = self.end_date.to_pydatetime()
@@ -87,10 +92,14 @@ def read_config(self, external_logger=None, awsm=None):
                 self.run_dirs = [self.run_dirs]
 
     else:
+        directory = ucfg.cfg['run']['directory']
+
+        if len(directory) == 1:
+            directory = directory[0]
+
         if self.all_subdirs is True:
-            self.run_dirs = ([ucfg.cfg['run']['directory'] + s for s in
-                            os.listdir(ucfg.cfg['run']['directory'])
-                            if (os.path.isdir(ucfg.cfg['run']['directory'] + s)) ])
+            self.run_dirs = ([directory + s for s in os.listdir(directory)
+                            if (os.path.isdir(directory + s))])
         else:
             self.run_dirs = ucfg.cfg['run']['directory']
             if type(self.run_dirs) != list:
@@ -109,6 +118,24 @@ def read_config(self, external_logger=None, awsm=None):
     self.db_port = ucfg.cfg['database']['port']
     self.db_convert = ucfg.cfg['database']['convert_ws']
     self.add_basins = ucfg.cfg['database']['add_basins']
+    self.db_overwrite = ucfg.cfg['database']['overwrite']
+    self.properties = ucfg.cfg['database']['properties']
+
+    base_bands = ['swi_z','evap_z','swe_z','depth','density',
+        'coldcont', 'precip_z']
+
+    f = False
+    for band in base_bands:
+        if band not in self.properties:
+            self.tmp_log.append(' WARNING! Config option [database] properties '
+                'does not contain {}'.format(band))
+            f = True
+
+    if f:
+        self.tmp_log.append(' WARNING! Suggest config option [database] '
+            'properties contain at least {} for most functionality to '
+            'run'.format(base_bands))
+
     if ((self.mysql is not None) and
         ((self.db_user is None) or
          (self.db_password is None) or
@@ -144,6 +171,49 @@ def read_config(self, external_logger=None, awsm=None):
     self.wxdb_password = ucfg.cfg['validate']['password']
     self.wxdb_host = ucfg.cfg['validate']['host']
     self.wxdb_port = ucfg.cfg['validate']['port']
+    self.point_values = ucfg.cfg['validate']['point_values']
+    self.point_values_csv = ucfg.cfg['validate']['point_values_csv']
+    self.point_values_date = ucfg.cfg['validate']['point_values_date']
+    self.point_values_properties = ucfg.cfg['validate']['point_values_properties']
+    self.point_values_heading = ucfg.cfg['validate']['point_values_heading']
+    self.point_values_settings = ucfg.cfg['validate']['point_values_settings']
+
+    if len(self.point_values_settings) != 14:
+        self.tmp_log.append(' Expected [validate] point_values_settings to '
+                            'have 14 values, point_values being set to False')
+        self.point_values = False
+
+    for n in range(0,10):
+        self.point_values_settings[n] = int(self.point_values_settings[n])
+
+    if type(self.point_values_properties) != list:
+        self.point_values_properties = [self.point_values_properties]
+
+    if type(self.point_values_heading) != list:
+        self.point_values_heading = [self.point_values_heading]
+
+    if type(self.point_values_csv) != list:
+        self.point_values_csv = [self.point_values_csv]
+
+    if self.point_values and self.point_values_csv is None:
+        self.point_values = False
+        self.tmp_log.append(' Config option [validate] point_values_csv '
+                            'was not supplied, point_values being set '
+                            'to False')
+
+    if self.point_values and self.point_values_date is None:
+        self.point_values = False
+        self.tmp_log.append(' Config option [validate] point_values_date '
+                            'was not supplied, point_values being set '
+                            'to False')
+
+    if not (len(self.point_values_csv) == len(self.point_values_properties) ==
+            len(self.point_values_heading)):
+        self.tmp_log.append(' Must supply the same number of [validate] '
+                            'point_values_csv, point_values_properties, '
+                            'and point_values_heading values, point_values '
+                            'being set to False')
+
 
     ####################################################
     #           diagnostics                            #
@@ -159,9 +229,33 @@ def read_config(self, external_logger=None, awsm=None):
                     self.tmp_log.append(' Config option [diagnostics] basin: {} '
                                         'does not match what was supplied in '
                                         '[snowav] masks: {}, diagnostics set '
-                                        'to False'.format(basin, plotorder))
+                                        'to False'.format(basin, self.plotorder))
                     self.diagnostics_flag = False
 
+    self.inputs_flag = ucfg.cfg['diagnostics']['inputs_table']
+    self.inputs_variables = ucfg.cfg['diagnostics']['inputs_variables']
+    self.inputs_percentiles = ucfg.cfg['diagnostics']['inputs_percentiles']
+    self.inputs_methods = ucfg.cfg['diagnostics']['inputs_methods']
+    self.inputs_basins = ucfg.cfg['diagnostics']['inputs_basins']
+
+    # if self.inputs_flag:
+    if self.inputs_basins is not None and self.plotorder is not None:
+        for basin in self.inputs_basins:
+            if basin not in self.plotorder:
+                self.tmp_log.append(' Config option [diagnostics] '
+                                    'inputs_basins: {} does not match what '
+                                    'was supplied in [snowav] masks: {}, '
+                                    'inputs set to '
+                                    'False'.format(basin, plotorder))
+                self.inputs_flag = False
+
+    if self.inputs_flag:
+        s = [x + ', ' for x in self.inputs_variables]
+        self.tmp_log.append(' Using variables {} for inputs summary'.format(''.join(s)))
+
+        s = [x + ', ' for x in self.inputs_methods]
+        self.tmp_log.append(' Using methods {} for inputs summary'.format(''.join(s)))
+
     ####################################################
     #          plots                                   #
     ####################################################
@@ -176,16 +270,17 @@ def read_config(self, external_logger=None, awsm=None):
     self.image_change_flag = ucfg.cfg['plots']['image_change']
     self.cold_content_flag = ucfg.cfg['plots']['cold_content']
     self.swe_volume_flag = ucfg.cfg['plots']['swe_volume']
-    self.swe_change_flag = ucfg.cfg['plots']['swe_change']
     self.basin_total_flag = ucfg.cfg['plots']['basin_total']
-    self.pixel_swe_flag = ucfg.cfg['plots']['pixel_swe']
     self.stn_validate_flag = ucfg.cfg['plots']['stn_validate']
     self.nash_sut_flag = ucfg.cfg['plots']['disp_nash_sut']
     self.stns_file = ucfg.cfg['plots']['stns_file']
     self.precip_validate_flag = ucfg.cfg['plots']['precip_validate']
+    self.inputs_fig_flag = ucfg.cfg['plots']['inputs']
+    self.plots_inputs_variables = ucfg.cfg['plots']['inputs_variables']
     self.compare_runs_flag = ucfg.cfg['plots']['compare_runs']
     self.compare_run_names = ucfg.cfg['plots']['compare_run_names']
     self.compare_run_labels = ucfg.cfg['plots']['compare_run_labels']
+    self.compare_run_wys = ucfg.cfg['plots']['compare_run_wys']
     self.precip_depth_flag = ucfg.cfg['plots']['precip_depth']
     self.basin_detail_flag = ucfg.cfg['plots']['basin_detail']
     self.update_file = ucfg.cfg['plots']['update_file']
@@ -193,6 +288,7 @@ def read_config(self, external_logger=None, awsm=None):
     self.figsize = (ucfg.cfg['plots']['fig_length'],
                     ucfg.cfg['plots']['fig_height'])
     self.write_properties = ucfg.cfg['plots']['write_properties']
+    self.point_values_flag = ucfg.cfg['plots']['point_values']
     if self.write_properties is not None and type(self.write_properties) != list:
         self.write_properties = [self.write_properties]
 
@@ -207,10 +303,11 @@ def read_config(self, external_logger=None, awsm=None):
         self.update_numbers = None
 
     if (self.compare_runs_flag and ((self.compare_run_names is None) or
-        (self.compare_run_labels is None))):
+        (self.compare_run_labels is None) or self.compare_run_wys is None)):
         self.tmp_log.append(' Config option [plots] compare_runs set to True, '
-                            'but one of compare_run_names or compare_run_labels '
-                            'is empty, resetting compare_runs to False')
+                            'but one of compare_run_names, compare_run_labels, '
+                            'or compare_run_wys is empty, setting '
+                            'compare_runs to False')
         self.compare_runs_flag = False
 
     if (self.compare_runs_flag and
@@ -241,6 +338,14 @@ def read_config(self, external_logger=None, awsm=None):
 
         self.stn_validate_flag = False
 
+    for var in self.plots_inputs_variables:
+        if var not in self.inputs_variables:
+            self.plots_inputs_variables.remove(var)
+            self.tmp_log.append(' Config option [plots] inputs_variables '
+                                'value {} not present in [diagnostics] '
+                                'inputs_variables, being removed'.format(var))
+
+
     ####################################################
     #          report                                  #
     ####################################################
@@ -256,6 +361,22 @@ def read_config(self, external_logger=None, awsm=None):
     self.figs_tpl_path = ucfg.cfg['report']['figs_tpl_path']
     self.flight_figs = ucfg.cfg['report']['flight_figs']
     self.tables = ucfg.cfg['report']['tables']
+    self.report_diagnostics = ucfg.cfg['report']['diagnostics']
+    self.report_diagnostics_day = ucfg.cfg['report']['diagnostics_day']
+    self.rep_dplcs = ucfg.cfg['report']['decimals']
+
+    if self.report_diagnostics and (not self.inputs_fig_flag or not self.diagnostics_flag):
+        self.tmp_log.append(" [report] diagnostics: True, but must also have "
+            "[plots] inputs: True and [diagnostics] diagnostics: True, "
+            "setting to False")
+        self.report_diagnostics = False
+
+    if self.report_diagnostics and self.report_diagnostics_day[0] != 'any':
+
+        if calendar.day_name[datetime.now().weekday()] not in self.report_diagnostics_day:
+            self.report_diagnostics = False
+            self.tmp_log.append(" Per [report] diagnostics_day: {}, "
+                "setting diagnostics: False".format(self.report_diagnostics_day))
 
     self.rep_swi_flag = ucfg.cfg['report']['swi']
     if not self.swi_flag:
@@ -291,20 +412,15 @@ def read_config(self, external_logger=None, awsm=None):
 
     # check paths to see if they need default snowav path
     if self.env_path is None:
-        self.env_path = os.path.join(self.snowav_path,
-                                     'snowav/report/template/section_text/')
+        self.env_path = os.path.abspath('./snowav/report/template/section_text')
     if self.templ_path is None:
-        self.templ_path = os.path.join(self.snowav_path,
-                                       'snowav/report/template/')
+        self.templ_path = os.path.abspath('./snowav/report/template')
     if self.summary_file is None:
-        self.summary_file = os.path.join(self.snowav_path,
-                      'snowav/report/template/section_text/report_summary.txt')
+        self.summary_file = os.path.abspath('./snowav/report/template/section_text/report_summary.txt')
     if self.tex_file is None:
-        self.tex_file = os.path.join(self.snowav_path,
-                                     'snowav/report/template/snowav_report.tex')
+        self.tex_file = os.path.abspath('./snowav/report/template/snowav_report.tex')
     if self.figs_tpl_path is None:
-        self.figs_tpl_path = os.path.join(self.snowav_path,
-                                          'snowav/report/figs/')
+        self.figs_tpl_path = os.path.abspath('./snowav/report/figs')
 
     ####################################################
     #           forecast                               #
