@@ -1,8 +1,9 @@
 
 from snowav.database.database import collect
 import pandas as pd
+from datetime import timedelta
 
-def write_properties(args, values):
+def write_properties(args, values, logger):
     '''
     Write daily total snowpack properties to csv.
 
@@ -15,10 +16,13 @@ def write_properties(args, values):
 
     '''
 
+    datestr = args['end_date'] + timedelta(hours=24)
+    datestr = datestr.strftime("%Y%m%d")
+
     for value in values:
         out = collect(args['connector'], args['plotorder'], args['basins'],
-                      args['wy_start'],args['end_date'],value,
-                      args['run_name'],'total','daily')
+                args['wy_start'], args['end_date'], value, args['run_name'],
+                'total','daily')
 
         if 'vol' in value or 'avail' in value:
             unit = args['vollbl']
@@ -32,6 +36,8 @@ def write_properties(args, values):
         if value == 'coldcont':
             unit = 'MJ'
 
-        path = '{}{}_{}_{}.csv'.format(args['figs_path'], value,
-                                       args['run_name'], unit)
+        path = '{}{}_timeseries_{}_{}.csv'.format(args['figs_path'], value, datestr, unit.lower())
+
+        logger.info(' saving {}'.format(path))
+
         out.to_csv(path)
