@@ -43,6 +43,7 @@ def report(self):
     edges = self.edges
     plotorder = self.plotorder
     dpts = int(self.dplcs)
+    ddpts = int(self.rep_dplcs)
     cnx = self.connector
 
     # variables to pass to latex file
@@ -66,12 +67,12 @@ def report(self):
 
     dbval = collect(cnx,plotorder[0],basins,start_date,end_date,'swe_z',
                     run_name,'total','end')
-    variables['TOTAL_PM'] = dbval.sum().values.round(decimals=dpts)[0]
+    variables['TOTAL_PM'] = dbval.sum().values.round(decimals=ddpts)[0]
 
     if self.precip_flag:
         dbval = collect(cnx,plotorder[0],basins,wy_start,end_date,'precip_z',
                         run_name,'total','sum')
-        variables['TOTALPRE_PM'] = dbval.sum().values.round(decimals=dpts)[0]
+        variables['TOTALPRE_PM'] = dbval.sum().values.round(decimals=ddpts)[0]
     else:
         variables['TOTALPRE_PM'] = 0
 
@@ -95,12 +96,12 @@ def report(self):
     if self.precip_flag:
         dbval = collect(cnx,plotorder[0],basins,wy_start,end_date,'rain_z',
                         run_name,'total','sum')
-        total_rain = dbval.sum().values.round(decimals=dpts)[0]
+        total_rain = dbval.sum().values.round(decimals=ddpts)[0]
     else:
         total_rain = 0.0
 
     if variables['TOTALPRE_PM'] != 0:
-        variables['TOTAL_RAT'] = r'$\sim$' + str(int((total_rain/variables['TOTALPRE_PM'])*100))
+        variables['TOTAL_RAT'] = str(int((total_rain/variables['TOTALPRE_PM'])*100))
     else:
         variables['TOTAL_RAT'] = '-'
         variables['TOTALPRE_PM'] = '-'
@@ -147,15 +148,15 @@ def report(self):
 
         dbval = collect(cnx,sub,basins,start_date,end_date,'swe_z',
                         run_name,'total','end')
-        variables[PM] = dbval.sum().values.round(decimals=dpts)[0]
+        variables[PM] = dbval.sum().values.round(decimals=ddpts)[0]
 
         dbval = collect(cnx,sub,basins,wy_start,end_date,'precip_z',
                         run_name,'total','sum')
-        variables[PREPM] = dbval.sum().values.round(decimals=dpts)[0]
+        variables[PREPM] = dbval.sum().values.round(decimals=ddpts)[0]
 
         dbval = collect(cnx,sub,basins,wy_start,end_date,'rain_z',
                         run_name,'total','sum')
-        variables[RAIN] = dbval.sum().values.round(decimals=dpts)[0]
+        variables[RAIN] = dbval.sum().values.round(decimals=ddpts)[0]
 
         if (end_swe > 0) and (variables['TOTAL_SWE'] > 0):
             variables[PVOL] = end_swe/variables['TOTAL_SWE']*100
@@ -178,23 +179,26 @@ def report(self):
         variables['REPORT_TITLE'] = title
 
     else:
-        if self.flt_flag:
+        if self.flt_flag and self.flight_figs:
             variables['REPORT_TITLE'] = self.rep_title + r' \\ ASO Updates'
             fst = ' Model snow depths were updated with ASO snow depths on '
-
             for i,d in enumerate(self.flight_diff_dates):
-                # self.flight_diff_dates
-                dn = d.date().strftime("%m/%d")
-                if len(self.flight_diff_dates) == 1:
-                    fst = fst + dn + '.'
+                if d <= self.end_date:
+                    dn = d.date().strftime("%m/%d")
+                    if len(self.flight_diff_dates) == 1:
+                        fst = fst + dn + '.'
 
-                if ((len(self.flight_diff_dates) > 1) and
-                    (i < len(self.flight_diff_dates) - 1)):
-                    fst = fst + dn + ', '
+                    if ((len(self.flight_diff_dates) > 1) and
+                        (i < len(self.flight_diff_dates) - 1)):
+                        fst = fst + dn + ', '
 
-                if ((len(self.flight_diff_dates) > 1) and
-                    (i == len(self.flight_diff_dates) - 1)):
-                    fst = fst + 'and ' + dn + '.'
+                    if ((len(self.flight_diff_dates) > 1) and
+                        (i == len(self.flight_diff_dates) - 1)):
+                        fst = fst + 'and ' + dn + '.'
+
+                else:
+                    fst = fst.split(dn)[0] + 'and ' + dn + '.'
+                    break
 
             variables['FLTSENT'] = fst
 
@@ -225,11 +229,11 @@ def report(self):
     variables['SWE_FIG'] = 'swe_volume_{}.png'.format(self.directory)
     variables['VERSION'] = snowav.__version__
 
-    if (self.update_file is not None) and self.flt_flag :
+    if (self.update_file is not None) and self.flt_flag and self.flight_figs:
         for name in self.flight_diff_fig_names:
             variables['DFLT_FIG'] = name
 
-    if self.forecast_flag is True:
+    if self.forecast_flag:
         variables['FORE_START_DATE'] = self.for_start_date.date().strftime("%B %-d")
         variables['FORE_DATE'] = self.for_end_date.date().strftime("%B %-d")
         variables['SWEFORECAST_FIG'] = 'swe_volume_{}.png'.format(self.directory + '_forecast')
@@ -238,20 +242,24 @@ def report(self):
         variables['TOTALSFORECAST_FIG'] = 'basin_total_{}.png'.format(self.directory + '_forecast')
         variables['PDEPFORECAST_FIG'] = 'precip_depth_{}.png'.format(self.directory + '_forecast')
 
+    if self.report_diagnostics:
+        variables['DIAGNOSTICS_FIG'] = 'diagnostics_{}'.format(self.directory)
+        variables['INPUTS_FIG'] = 'inputs_period_{}'.format(self.directory)
+
     if self.subs_fig is not None:
         variables['SUBBASINS_FIG'] = '{}'.format(self.subs_fig)
 
     # Logos
-    variables['ARSLOGO'] = self.figs_tpl_path + 'ARS.jpg'
-    variables['ASOLOGO'] = self.figs_tpl_path + 'ASO.jpg'
-    variables['USDALOGO'] = self.figs_tpl_path + 'USDA.png'
-    variables['JPLLOGO'] = self.figs_tpl_path + 'JPL.jpg'
-    variables['CDWRLOGO'] = self.figs_tpl_path + 'CDWR.png'
-    variables['USBRLOGO'] = self.figs_tpl_path + 'USBR.jpg'
-    variables['NRCSLOGO'] = self.figs_tpl_path + 'NRCS.jpg'
-    variables['KRWALOGO'] = self.figs_tpl_path + 'KRWA.jpg'
-    variables['FRIANTLOGO'] = self.figs_tpl_path + 'FRIANT.jpg'
-    variables['AWSMLOGO'] = self.figs_tpl_path + 'logo.png'
+    variables['ARSLOGO'] = os.path.join(self.figs_tpl_path, 'ARS.jpg')
+    variables['ASOLOGO'] = os.path.join(self.figs_tpl_path, 'ASO.jpg')
+    variables['USDALOGO'] = os.path.join(self.figs_tpl_path, 'USDA.png')
+    variables['JPLLOGO'] = os.path.join(self.figs_tpl_path, 'JPL.jpg')
+    variables['CDWRLOGO'] = os.path.join(self.figs_tpl_path, 'CDWR.png')
+    variables['USBRLOGO'] = os.path.join(self.figs_tpl_path, 'USBR.jpg')
+    variables['NRCSLOGO'] = os.path.join(self.figs_tpl_path, 'NRCS.jpg')
+    variables['KRWALOGO'] = os.path.join(self.figs_tpl_path, 'KRWA.jpg')
+    variables['FRIANTLOGO'] = os.path.join(self.figs_tpl_path, 'FRIANT.jpg')
+    variables['AWSMLOGO'] = os.path.join(self.figs_tpl_path, 'logo.png')
 
     dfind = [str(i) for i in self.edges]
     dfindt = [str(i) for i in self.edges] + ['total']
@@ -269,12 +277,13 @@ def report(self):
     if 'swe_depth' in self.tables:
 
         dbval = collect(cnx,plotorder,basins,start_date,end_date,'swe_z',run_name,dfindt,'end')
+        dbval = dbval.rename(columns=self.labels)
         swe_byelev = dbval.round(decimals=dpts)
         swe_byelev.rename(index={'total':'mean'},inplace=True)
         swe_byelev.index.name = 'Elevation'
         variables['SWE_BYELEV'] = (r' \normalsize \textbf{SWE [%s], %s}\\ \vspace{0.1cm} \\'
                                     %(self.depthlbl,self.report_date.date().strftime("%Y-%-m-%-d")) +
-                                    spacecmd + swe_byelev[plotorder].to_latex(na_rep='-', column_format=colstr) +
+                                    spacecmd + swe_byelev.to_latex(na_rep='-', column_format=colstr) +
                                     r'} \\ \footnotesize{\textbf{Table %s:} SWE depth.}'%(str(mtables)))
         mtables += 1
         ptables += 1
@@ -290,11 +299,12 @@ def report(self):
         else:
             clrpage = ''
         dbval = collect(cnx,plotorder,basins,start_date,end_date,'swe_vol',run_name,dfindt,'end')
+        dbval = dbval.rename(columns=self.labels)
         swe_byelev = dbval.round(decimals=dpts)
         swe_byelev.index.name = 'Elevation'
         variables['SWEVOL_BYELEV'] = (r' \normalsize \textbf{SWE [%s], %s}\\ \vspace{0.1cm} \\'
                                     %(self.vollbl,self.report_date.date().strftime("%Y-%-m-%-d")) +
-                                    spacecmd + swe_byelev[plotorder].to_latex(na_rep='-', column_format=colstr) +
+                                    spacecmd + swe_byelev.to_latex(na_rep='-', column_format=colstr) +
                                     r'} \\ \footnotesize{\textbf{Table %s:} SWE volume.}%s'%(str(mtables),clrpage))
         mtables += 1
 
@@ -309,8 +319,10 @@ def report(self):
         else:
             clrpage = ''
         dbval = collect(cnx,plotorder,basins,start_date,start_date,'swe_z',run_name,dfindt,'end')
+        dbval = dbval.rename(columns=self.labels)
         start_swe = dbval.round(decimals=dpts)
         dbval = collect(cnx,plotorder,basins,start_date,end_date,'swe_z',run_name,dfindt,'end')
+        dbval = dbval.rename(columns=self.labels)
         end_swe = dbval.round(decimals=dpts)
         dswe_byelev = end_swe - start_swe
         dswe_byelev.rename(index={'total':'mean'},inplace=True)
@@ -318,7 +330,7 @@ def report(self):
         variables['DSWE_BYELEV'] = (r'  \normalsize \textbf{Change in SWE [%s], %s to %s}\\ \vspace{0.1cm} \\'
                                     %(self.depthlbl,self.report_start.date().strftime("%Y-%-m-%-d"),
                                       self.report_date.date().strftime("%Y-%-m-%-d")) + spacecmd +
-                                      dswe_byelev[self.plotorder].to_latex(na_rep='-', column_format=colstr) +
+                                      dswe_byelev.to_latex(na_rep='-', column_format=colstr) +
                                       r'} \\ \footnotesize{\textbf{Table %s:} Change in SWE.} %s'%(str(mtables),clrpage))
         mtables += 1
 
@@ -333,6 +345,7 @@ def report(self):
             clrpage = ''
 
         dbval = collect(cnx,plotorder,basins,start_date,end_date,'swe_vol',run_name,dfind,'end')
+        dbval = dbval.rename(columns=self.labels)
         swe_byelev = dbval.round(decimals=dpts)
         value = swe_byelev.iloc[:-1].sum()
         sweper_byelev = (swe_byelev/value*100).round(decimals = dpts)
@@ -340,7 +353,7 @@ def report(self):
 
         variables['SWEPER_BYELEV'] = (r'  \normalsize \textbf{SWE volume, percent of basin total, %s}\\ \vspace{0.1cm} \\'
                                     %(self.report_date.date().strftime("%Y-%-m-%-d"))+
-                                    spacecmd + sweper_byelev[plotorder].round(1).to_latex(na_rep='-', column_format=colstr) +
+                                    spacecmd + sweper_byelev.round(1).to_latex(na_rep='-', column_format=colstr) +
                                     r'}  \\ \footnotesize{\textbf{Table %s:} Percent of total SWE volume.}%s'%(str(mtables),clrpage))
         variables['SWEPER_BYELEV'] = variables['SWEPER_BYELEV'].replace('inf','-')
 
@@ -351,11 +364,12 @@ def report(self):
 
     if 'swi_vol' in self.tables:
         dbval = collect(cnx,plotorder,basins,start_date,end_date,'swi_vol',run_name,dfindt,'sum')
+        dbval = dbval.rename(columns=self.labels)
         swi_byelev = dbval.round(decimals=dpts)
         variables['ACCUM_BYELEV'] = (r' \normalsize \textbf{SWI [%s] by elevation, %s to %s}\\ \vspace{0.1cm} \\'
                                     %(self.vollbl,self.report_start.date().strftime("%Y-%-m-%-d"),
                                       self.report_date.date().strftime("%Y-%-m-%-d")) + spacecmd +
-                                      swi_byelev[plotorder].to_latex(na_rep='-', column_format=colstr) +
+                                      swi_byelev.to_latex(na_rep='-', column_format=colstr) +
                                       r'} \\ \footnotesize{\textbf{Table %s:} SWI volume. }'%(str(mtables)))
         mtables += 1
 
@@ -364,9 +378,10 @@ def report(self):
 
     variables['TOT_LBL'] = self.plotorder[0]
 
-    for n in range(1,len(self.plotorder)):
+    # for n in range(1,len(self.plotorder)):
+    for n in range(1,len(self.labels)):
         s = 'SUB' + str(n) + '_LBL'
-        variables[s] = self.plotorder[n]
+        variables[s] = self.labels[self.plotorder[n]]
 
     # Convert floats to strings
     for name in variables:
@@ -380,33 +395,38 @@ def report(self):
     # Summary sections and fig template have variable strings
     # (e.g. CHANGES_FIG) that need to be replaced
     section_dict = {'SUMMARY':self.summary_file,
-                    'CHANGES_FIG_TPL':self.figs_tpl_path + 'changes_fig_tpl.txt',
-                    'SWI_FIG_TPL':self.figs_tpl_path + 'swi_fig_tpl.txt',
-                    'TOTALS_FIG_TPL':self.figs_tpl_path + 'totals_fig_tpl.txt',
-                    'MULTITOTSWE_FIG_TPL':self.figs_tpl_path + 'multitotswe_fig_tpl.txt',
-                    'VALID_FIG_TPL':self.figs_tpl_path + 'valid_fig_tpl.txt',
-                    'FLTCHANGES_FIG_TPL':self.figs_tpl_path + 'flt_fig_tpl.txt',
-                    'PDEP_FIG_TPL':self.figs_tpl_path + 'pdep_fig_tpl.txt',
-                    'COLD_FIG_TPL':self.figs_tpl_path + 'cold_fig_tpl.txt',
-                    'SWE_FIG_TPL':self.figs_tpl_path + 'swe_fig_tpl.txt',
-                    'SUBBASINS_FIG_TPL':self.figs_tpl_path + 'subbasins_fig_tpl.txt',
-                    'SWEFORECAST_FIG_TPL':self.figs_tpl_path + 'forecastswe_fig_tpl.txt',
-                    'SWIFORECAST_FIG_TPL':self.figs_tpl_path + 'forecastswi_fig_tpl.txt',
-                    'CHANGESFORECAST_FIG_TPL':self.figs_tpl_path + 'forecastchanges_fig_tpl.txt',
-                    'TOTALSFORECAST_FIG_TPL':self.figs_tpl_path + 'forecasttotals_fig_tpl.txt',
-                    'PDEPFORECAST_FIG_TPL':self.figs_tpl_path + 'forecastpdep_fig_tpl.txt'
+                    'CHANGES_FIG_TPL':os.path.join(self.figs_tpl_path, 'changes_fig_tpl.txt'),
+                    'SWI_FIG_TPL':os.path.join(self.figs_tpl_path, 'swi_fig_tpl.txt'),
+                    'TOTALS_FIG_TPL':os.path.join(self.figs_tpl_path, 'totals_fig_tpl.txt'),
+                    'MULTITOTSWE_FIG_TPL':os.path.join(self.figs_tpl_path, 'multitotswe_fig_tpl.txt'),
+                    'VALID_FIG_TPL':os.path.join(self.figs_tpl_path, 'valid_fig_tpl.txt'),
+                    'FLTCHANGES_FIG_TPL':os.path.join(self.figs_tpl_path, 'flt_fig_tpl.txt'),
+                    'PDEP_FIG_TPL':os.path.join(self.figs_tpl_path, 'pdep_fig_tpl.txt'),
+                    'COLD_FIG_TPL':os.path.join(self.figs_tpl_path, 'cold_fig_tpl.txt'),
+                    'SWE_FIG_TPL':os.path.join(self.figs_tpl_path, 'swe_fig_tpl.txt'),
+                    'SUBBASINS_FIG_TPL':os.path.join(self.figs_tpl_path, 'subbasins_fig_tpl.txt'),
+                    'SWEFORECAST_FIG_TPL':os.path.join(self.figs_tpl_path, 'forecastswe_fig_tpl.txt'),
+                    'SWIFORECAST_FIG_TPL':os.path.join(self.figs_tpl_path, 'forecastswi_fig_tpl.txt'),
+                    'CHANGESFORECAST_FIG_TPL':os.path.join(self.figs_tpl_path, 'forecastchanges_fig_tpl.txt'),
+                    'TOTALSFORECAST_FIG_TPL':os.path.join(self.figs_tpl_path, 'forecasttotals_fig_tpl.txt'),
+                    'PDEPFORECAST_FIG_TPL':os.path.join(self.figs_tpl_path, 'forecastpdep_fig_tpl.txt'),
+                    'DIAGNOSTICS_FIG_TPL':os.path.join(self.figs_tpl_path, 'diagnostics_fig_tpl.txt')
                     }
 
     # Define and load summary tables depending on number of subbasins
-    section_dict['SWE_SUMMARY_TPL'] = '{}swe_summary_{}sub.txt'.format(
-                                    self.figs_tpl_path,str(len(self.plotorder)))
+    section_dict['SWE_SUMMARY_TPL'] = os.path.join(self.figs_tpl_path,
+        'swe_summary_{}sub.txt'.format(str(len(self.plotorder))))
 
     # Remove if no flight
-    if self.flt_flag is False:
+    if not self.flt_flag or not self.flight_figs:
         del section_dict['FLTCHANGES_FIG_TPL']
 
+    if not self.report_diagnostics:
+        del section_dict['DIAGNOSTICS_FIG_TPL']
+        variables['DIAGNOSTICS_FIG'] = ''
+
     # Remove if no forecast
-    if self.forecast_flag is False:
+    if not self.forecast_flag:
         del section_dict['SWEFORECAST_FIG_TPL']
         del section_dict['SWIFORECAST_FIG_TPL']
         del section_dict['CHANGESFORECAST_FIG_TPL']
@@ -512,9 +532,9 @@ def report(self):
     # Save in reports and with figs
     rpath = os.path.join(self.figs_path, '' + self.report_name)
     pdf.save_to(rpath)
-    self._logger.info(' saving {}'.format(rpath))
+    self._logger.info(' Saved {}'.format(rpath))
 
     if self.rep_path is not None:
         rpath = os.path.join(self.rep_path, '' + self.report_name)
         pdf.save_to(rpath)
-        self._logger.info(' saving {}'.format(rpath))
+        self._logger.info(' Saved {}'.format(rpath))
