@@ -6,6 +6,8 @@ import numpy as np
 import copy
 from collections import OrderedDict
 from snowav.database.database import convert_watershed_names
+from tablizer.tablizer import summarize, store, get_existing_records
+from tablizer.inputs import Inputs
 
 def calculate(array, pixel, masks = None, method = 'sum', convert = None,
               units = 'TAF', decimals = 3):
@@ -85,13 +87,14 @@ def calculate(array, pixel, masks = None, method = 'sum', convert = None,
         if convert == 'depth':
             factor = 0.1
 
-        # snow depth remains m
+        # m to cm
         if convert == 'snow_depth':
-            factor = 1
+            factor = 100
 
         # mm/pixel to MM^3
         if convert == 'volume':
             factor = (pixel**2)*0.000000810713194*1233.48/1e9
+             # ((self.pixel**2)*0.000000810713194*0.001)
 
     if convert is None:
         factor = 1
@@ -112,16 +115,20 @@ def calculate(array, pixel, masks = None, method = 'sum', convert = None,
 
     # make calculation and convert
     if method == 'sum':
-        value = np.nansum(array) * factor
+        if np.sum(np.isnan(array)) == array.size:
+            value = np.nan
+        else:
+            value = np.nansum(array) * factor
 
     if method == 'mean':
         value = np.nanmean(array) * factor
 
-    value = value.round(decimals)
+    if not np.isnan(value):
+        value = value.round(decimals)
 
     return value
 
-def snow_line(array, dem, masks = None, limit = 1):
+def snow_line(array, dem, masks = None, limit = 0.01):
     '''
     Calculate mean snow line in image.
 
@@ -154,10 +161,9 @@ def snow_line(array, dem, masks = None, limit = 1):
 
     ix = array > limit
 
-    if not np.isnan(np.nanmean(dem[ix])):
-        value = int(np.nanmean(dem[ix]))
-
-    else:
+    try:
+        value = int(np.nanpercentile(dem[ix].flatten(), [2,90])[0])
+    except:
         value = np.nan
 
     return value
@@ -198,6 +204,7 @@ def masks(dempath, convert, plotorder = None, plotlabels = None):
 
     ncf = nc.Dataset(dempath, 'r')
     dem = ncf.variables['dem'][:]
+    veg_type = ncf.variables['veg_type'][:]
 
     mask_names = [ncf.variables['mask'].long_name]
     mask_names_total = ncf.variables['mask'].long_name
@@ -268,6 +275,7 @@ def masks(dempath, convert, plotorder = None, plotlabels = None):
         labels[new_key] = labels.pop(old_key)
 
     out['dem'] = dem
+    out['veg_type'] = veg_type
     out['masks'] = masks
     out['nrows'] = nrows
     out['ncols'] = ncols
@@ -339,6 +347,44 @@ def precip(rundirs_dict, path):
     return flag, ppt_path, precip, rain
 
 
+def input_summary(path, variable, methods, percentiles, database, location,
+                  run_name, basin_id, run_id, masks):
+    '''
+    Summarize smrf outputs with tablizer.
+
+    Args
+    ------
+    path : str
+    variable : str
+    methods : list
+    percentiles : list
+    database : str
+    location : str
+    run_name : str
+    basin_id : int
+    run_id : int
+    masks : list
+
+    '''
+
+    ncf = nc.Dataset(path, 'r')
+    array = ncf.variables[variable][:]
+    dates = ncf.variables['time'][:]
+    date_units = ncf.variables['time'].units
+    ncf.close()
+
+    if len(array[:]) > 24:
+        nb = 24
+    else:
+        nb = len(array[:])
+
+    for nb in range(0,nb):
+        date = nc.num2date(dates[nb],date_units)
+        slice = array[nb,:,:]
+        results = summarize(slice, date, methods, [percentiles[0], percentiles[1]], 3, masks)
+        store(results, variable, database, location, run_name, basin_id,
+              run_id, date)
+
 def getgitinfo():
     """gitignored file that contains specific SNOWAV version and path
 
